@@ -30,10 +30,11 @@ class QWidgetAction;
 class KToggleAction;
 #include <kstatusnotifieritem.h>
 
-class KMenu;
+class QMenu;
 class KMixWindow;
 class Mixer;
 #include "core/mixdevice.h"
+#include "core/ControlManager.h"
 class ViewDockAreaPopup;
 class Volume;
 
@@ -54,8 +55,8 @@ class KMixDockWidget : public KStatusNotifierItem
  public slots:
    void setVolumeTip();
    void updatePixmap();
-   void activate(const QPoint &pos);
-   void controlsChange(int changeType);
+   void activate(const QPoint &pos) Q_DECL_OVERRIDE;
+   void controlsChange(ControlManager::ChangeType changeType);
 
  protected:
    void createMenuActions();
@@ -63,7 +64,7 @@ class KMixDockWidget : public KStatusNotifierItem
 
  private:
    ViewDockAreaPopup *_dockView;
-   KMenu *_dockAreaPopupMenuWrapper;
+   QMenu *_dockAreaPopupMenuWrapper;
    QWidgetAction *_volWA;
    int  _oldToolTipValue;
    char _oldPixmapType;
