@@ -21,43 +21,46 @@
 #ifndef ViewSliders_h
 #define ViewSliders_h
 
+#include "viewbase.h"
+
 class QBoxLayout;
-#include <QFrame>
-#include <QHash>
-class QLabel;
-#include <QPushButton>
-class QWidget;
+class QGridLayout;
+class QPushButton;
+class KMessageWidget;
 
 class Mixer;
-#include "viewbase.h"
+
+#include "gui/viewbase.h"
+#include "core/ControlManager.h"
+
 
 class ViewSliders : public ViewBase
 {
     Q_OBJECT
+
 public:
-    ViewSliders(QWidget* parent, QString id, Mixer* mixer, ViewBase::ViewFlags vflags, QString guiProfileId, KActionCollection *actColl);
+    ViewSliders(QWidget *parent, const QString &id, Mixer *mixer, ViewBase::ViewFlags vflags, const QString &guiProfileId, KActionCollection *actColl);
     virtual ~ViewSliders();
 
-    QWidget* add(shared_ptr<MixDevice>) Q_DECL_OVERRIDE;
+    QWidget *add(const shared_ptr<MixDevice> md) Q_DECL_OVERRIDE;
     void constructionFinished() Q_DECL_OVERRIDE;
     void configurationUpdate() Q_DECL_OVERRIDE;
 
 public slots:
-    void controlsChange(int changeType);
+    void controlsChange(ControlManager::ChangeType changeType);
 
 protected:
-    void _setMixSet() Q_DECL_OVERRIDE;
+    void initLayout() Q_DECL_OVERRIDE;
+    Qt::Orientation orientationSetting() const Q_DECL_OVERRIDE;
 
 private:
     void refreshVolumeLevels() Q_DECL_OVERRIDE;
 
-    QBoxLayout* _layoutMDW;
-    QLayout* _layoutSliders;
-	QBoxLayout* _layoutEnum;
-    QHash<QString,QFrame*> _separators;
-    QPushButton* _configureViewButton;
-    QLabel* emptyStreamHint;
+    QGridLayout *m_layoutMDW;
+    QBoxLayout *m_layoutSliders;
+    QBoxLayout *m_layoutSwitches;
+    QPushButton *m_configureViewButton;
+    KMessageWidget *m_emptyStreamHint;
 };
 
 #endif
-
